IGertecPrinterRepository class abstract

Implementers

Constructors

IGertecPrinterRepository()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

barcodePrint(BarcodePrint barcodePrint) Future<PrinterResponse>
checkStatusPrinter() Future<PrinterResponse>
cut() Future<PrinterResponse>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
printLine(TextPrint textPrint) Future<PrinterResponse>
printTextList(List<TextPrint> textPrintList) Future<PrinterResponse>
toString() String
A string representation of this object.
inherited
wrapLine(int lineQuantity) Future<PrinterResponse>

Operators

operator ==(Object other) bool
The equality operator.
inherited